@@ -26,8 +26,8 @@ Generic Access to Thruks Config
 
 ######################################
 
-our $VERSION = '3.25.20251130';
-our $GIT_HASH = "aca932ecf"; # set by dailydist make target
+our $VERSION = '3.25.20251202';
+our $GIT_HASH = "2bd044f5f"; # set by dailydist make target
 
 our $config;
 our $project_root = home() || confess('could not determine project_root from inc.');
@@ -35,7 +35,7 @@ our $project_root = home() || confess('could not determine project_root from inc
 my $base_defaults = {
     'name'                                  => 'Thruk',
     'fileversion'                           => $VERSION,
-    'released'                              => 'November 30, 2025',
+    'released'                              => 'December 02, 2025',
     'compression_format'                    => 'gzip',
     'ENCODING'                              => 'utf-8',
     'image_path'                            => $project_root.'/root/thruk/images',
